import 'whatwg-fetch';
export interface IBaseRequestArgs {
    apiUrl: string;
    accessKey?: string;
}
export interface IRequestGetErrorCodeArgs {
    warnings: Array<{
        Code: string;
    }>;
    errors: Array<{
        ErrorCode: string;
    }>;
}
export declare enum HTTP_Method {
    Get = "GET",
    Post = "POST"
}
export declare class BaseRequest<T extends object, U> {
    /**
     * Determines if a request fails based on the received response
     * @param response
     * @returns {boolean}
     */
    static containsError(response: {
        success: boolean | string;
    }): boolean;
    /**
     * Returns the error message from the response
     * @param response
     * @returns {string}
     */
    static getErrorMessage(response: {
        error: string;
        errors: Array<{
            Description: string;
        }>;
    }): string;
    /**
     * Returns the error message from the response
     * @param response
     * @returns {Number}
     */
    static getErrorCode(response: IRequestGetErrorCodeArgs): number;
    protected apiUrl: string;
    protected accessKey: string;
    /**
     * C-tor
     * @param {Object} args
     * @param {String} args.apiUrl - Full URL to the api end-point.
     */
    constructor(args: IBaseRequestArgs);
    /**
     * To be overwritten
     * @returns {string}
     */
    get endpointUrl(): string;
    /**
     * To be overwritten
     * @returns {string}
     */
    get method(): HTTP_Method;
    /**
     * To be overwritten
     * @returns {Object}
     */
    get defaultPayload(): {};
    /**
     * Execute!
     * @param payload
     * @returns {Promise}
     */
    execute(payload?: T): Promise<U>;
    /**
     * Yeah....
     * @param paramsObject
     * @returns {string}
     */
    toQueryString(paramsObject?: {
        [key: string]: string | string[];
    }): string;
    /**
     *
     * @param key
     * @param array
     * @returns {string}
     */
    toTraditionalArray(key: string, array: string[]): string;
    /**
     * Pass-through
     * @param {Object} payload
     * @returns {Object}
     */
    protected processRequestData(payload: any): any;
    /**
     * Pass-through
     * @param {Object} response
     * @returns {Object}
     */
    protected processResponseData(response: any): U;
}
