import { Endpoint } from '../common/endpoint';
import { IUserData } from "../request/connectService/createAccessKey";
import { IAccessKeyData } from "../request/connectService/setAccessKeyOptions";
export interface IAuthEndpointArgs {
    apiUrl: string;
    keepAliveInterval?: number;
}
export declare class Auth extends Endpoint {
    private keepAliveInterval;
    /**
     * C-tor
     * @param {Object} args
     * @param {String} args.apiUrl - Full URL to the api end-point.
     * @param {Number} [args.keepAliveInterval] - Timeout for making a keep alive request
     */
    constructor(args: IAuthEndpointArgs);
    /**
     * Logs in a user
     * @param {String} username - username to log in with
     * @param {String} password - password of said user
     * @returns {Promise}
     */
    createAccessKey({ username, password }: {
        username?: string | undefined;
        password?: string | undefined;
    }): Promise<IUserData>;
    /**
     *
     * @param accessKey
     * @param args
     */
    setAccessKeyOptions(accessKey: string, args: {
        versionId: string;
        languageId: number;
    }): Promise<IAccessKeyData>;
    /**
     * Gets accesskey info
     * @returns {Promise}
     */
    getAccessKeyInfo(args: {
        accessKey: string;
    }): Promise<any>;
    /**
     * Ahh, Ahh, Ahh, Ahh, Staying alive, staying alive
     * @returns {Promise}
     */
    keepAlive(args: {
        accessKey: string;
    }): Promise<IUserData>;
}
declare module '../connector' {
    interface Connector {
        auth: Auth;
    }
}
