import { Endpoint, IEndpointArgs } from '../common/endpoint';
import { Asset } from "../model/asset";
import { Filter } from "../model/filter/filter";
import { Folder } from "../model/folder";
import { AssetInformation as AssetInformationModel } from '../model/information/assetInformation';
export interface IContentEndpointArgs extends IEndpointArgs {
    labels?: {
        [key: string]: string;
    };
    metafieldLabelId?: string;
    sLayoutFolderId: string;
    labelsPromise: Promise<any>;
    sortTypes: any;
    defaultSortType: string;
}
export interface IContentCache {
    total: {
        [key: string]: any;
    };
    filters: {
        [key: string]: Filter[];
    };
    facetResult: {
        [key: string]: any;
    };
}
export interface ISortType {
    by: string;
    name: string;
    defaultDirection: string;
}
export interface IGetAssetArgs {
    path?: string;
    sorting?: {
        by: string;
        direction: string;
    };
    searchName?: string;
    navigation?: {
        page?: number;
        limit: number;
    };
    filters?: Filter[];
}
export declare class Content extends Endpoint {
    private metafieldLabelId?;
    private sLayoutFolderId;
    private labelsPromise;
    private labels;
    private rawSortTypes;
    private defaultSortType;
    private cache;
    private sortTypes;
    /**
     * C-tor
     * @param {Object} args
     * @param {String} args.apiUrl - Full URL to the api end-point.
     * @param {Object} args.labels - An object of labels
     * @param {String} args.metafieldLabelId - metafieldLabelId of the menu
     */
    constructor(args: IContentEndpointArgs);
    get SORT_TYPES(): ISortType[];
    /**
     * Default search
     * @returns {string}
     * @constructor
     */
    get DEFAULT_SEARCH(): string;
    /**
     * Return a list of available sort by fields
     * @returns {Array}
     */
    getSortBy(): ISortType[];
    /**
     * Get a list of folders
     * @param args
     * @param {String} [args.path] - Path under which to search for folders
     * @returns {Promise.<{folders}>}
     */
    getFolders(args: {
        path: string;
    }): Promise<{
        folders: Folder[];
    }>;
    /**
     * Get a list of folders
     * @param args
     * @param {String} [args.searchName] - The search for which to obtain the filters
     * @returns {Promise}
     */
    getFilters(args?: {
        searchName?: string;
    }): Promise<Filter[]>;
    /**
     * Get a list of assets
     * @param args
     * @param {String} [args.path] - The path holding the assets
     * @param {object} [args.sorting] - The sorting to apply
     * @param {string} [args.sorting.by] - The value to sort by
     * @param {string} [args.sorting.direction] - The sorting direction
     * @returns {Promise.<{assets, navigation}>}
     */
    getAssets(args?: IGetAssetArgs): Promise<{
        assets: Asset[];
        navigation: {
            total: number;
        };
    }>;
    /**
     *
     * @param args
     * @param {Number[]} [args.assetIds] -  a list of assets ids
     * @returns {Promise.<Asset[]>}
     */
    getAssetsById(args: {
        assetIds: number[];
    }): Promise<Asset[]>;
    getAssetsInformation(args: {
        assets: Asset[];
    }): Promise<AssetInformationModel[]>;
    /**
     * Get a list of facet results
     * @param args
     * @param {String} [args.searchName] - The path holding the assets
     * @returns {Object}
     */
    getFacetResult(args?: {
        searchName?: string;
    }): Promise<any>;
    /**
     * Parses sort types
     * @param sortTypes
     * @returns {*|Array}
     * @private
     */
    private _parseSortTypes;
    /**
     * Parse a sort type
     * @param sortType
     * @private
     */
    private _parseSortType;
}
declare module '../connector' {
    interface Connector {
        content: Content;
    }
}
