import { Endpoint, IEndpointArgs } from '../common/endpoint';
import { Asset } from "../model/asset";
export interface IDownloadArgs extends IEndpointArgs {
    memberId: number;
    lowResMediaFormatIds: number[];
    highResMediaFormatIds: number[];
    mediaUrl: string;
}
export declare class Download extends Endpoint {
    private memberId;
    private lowResMediaFormatIds;
    private highResMediaFormatIds;
    private mediaUrl;
    private cache;
    /**
     * C-tor
     * @param {Object} args
     */
    constructor(args: IDownloadArgs);
    /**
     * Returns a promise that resolves to the download URL of the asset
     * @param {Object} args
     * @param {Asset} args.asset
     * @param {Number} args.quality
     * @returns {Promise.<string>}
     */
    getDownloadURL(args: {
        asset: Asset;
        quality: number;
    }): Promise<string>;
    /**
     * Returns a URL for a required quality
     * @param args
     */
    getUrlForQuality(args: {
        asset: Asset;
        quality: number;
    }): Promise<string>;
    /**
     * Returns a promise that resolves to the download URL of the asset
     * @param {Object} args
     * @param {Asset} args.asset
     * @param {Number} args.mediaFormatId
     * @returns {String}
     */
    _getDownloadURLForFormat(args: {
        asset: Asset;
        mediaFormatId: number;
        download?: boolean;
    }): string;
    /**
     *
     * @param args
     * @returns {Promise}
     */
    getAllDownloadURL(args: {
        asset: Asset;
    }): Promise<Array<{
        quality: string;
        url: string;
    }>>;
    /**
     *  Returns a list of download qualities
     * @returns {Object}
     * @private
     */
    _getAllDownloadQualities(): Promise<any>;
    /**
     * HACK: Since the GetDownloadQualities does not support assets type
     * like InDesign, Photoshop and Illustator, we will manually clone the ones from
     * image to them
     * @param downloadQualities
     * @private
     */
    private _hackishlyAddDownloadQualitiesForAdobeFormats;
}
declare module '../connector' {
    interface Connector {
        download: Download;
    }
}
