import { Endpoint } from '../common/endpoint';
import { Asset } from "../model/asset";
import { Lock as LockModel } from "../model/lock";
export declare class Lock extends Endpoint {
    /**
     * Lock an asset
     * @param {Object} args
     * @param {Asset} args.asset - Asset for which to set the lock
     * @param {String} [args.note] - Note for locking the asset
     * @returns {Promise.<>}
     */
    lockAsset(args: {
        asset: Asset;
        note?: string;
    }): Promise<void>;
    /**
     * Unlock an asset
     * @param {Object} args
     * @param {Asset} args.asset - Asset to unlock
     * @param {String} [args.note] - Note for unlocking the asset
     * @returns {Promise.<>}
     */
    unlockAsset(args: {
        asset: Asset;
        note?: string;
    }): Promise<void>;
    /**
     * Returns the lock information for a given asset
     * @param {Object} args
     * @param {Asset} args.asset - Asset for which to get the lock information
     * @returns {Promise.<Lock>}
     */
    getLockInformation(args: {
        asset: Asset;
    }): Promise<LockModel>;
}
declare module '../connector' {
    interface Connector {
        lock: Lock;
    }
}
