import { Endpoint, IEndpointArgs } from '../common/endpoint';
import { Asset } from "../model/asset";
import { DateTimeMetadataItem } from '../model/metadata/dateTimeMetadataItem';
import { LanguageMetadataGroup } from '../model/metadata/languageMetadataGroup';
import { MetadataGroup } from "../model/metadata/metadataGroup";
import { MetadataItem } from '../model/metadata/metadataItem';
import { TreeMetadataItem } from '../model/metadata/treeMetadataItem';
import { UniqueVersionMetadataItem } from "../model/metadata/uniqueVersionMetadataItem";
import { IUpdateContainerAddItemArgs } from '../utilities/updateContainer';
export interface ILanguage {
    languageId: number;
    languageName: string;
}
export interface IMetadataArgs extends IEndpointArgs {
    language: number;
    languages: ILanguage[];
}
export interface IMetadataGetMetadataItemOptions {
    metadataItem: MetadataItem<any>;
    path?: string;
    navigation?: {
        page: number;
        limit: number;
    };
}
export declare class Metadata extends Endpoint {
    private language;
    private languages;
    /**
     * C-tor
     * @param {Object} args
     * @param {String} args.apiUrl - Full URL to the api end-point.
     */
    constructor(args: IMetadataArgs);
    /**
     * Returns a list of metadata groups
     * @param {Object} args
     * @param {Asset} args.asset - Asset for which to get the metadata
     */
    getMetadataGroups(args: {
        asset: Asset;
    }): Promise<any[]>;
    /**
     * Returns a list of language metadata
     * @returns {Promise.<Array>}
     */
    getLanguageMetadataGroups(): Promise<LanguageMetadataGroup[]>;
    /**
     * Returns a list of metadata items in a group
     * @param args
     * @param {Asset} args.asset
     * @param {MetadataGroup} args.group
     * @returns {Promise.<T>}
     */
    getMetadataItems(args: {
        asset: Asset;
        group: MetadataGroup;
    }): Promise<any>;
    /**
     *
     * @param args
     * @param {Asset[]} args.assets
     * @param {Array} args.metadataItems
     * @returns {Promise.<T>}
     */
    updateMetadataItems(args: {
        assets: Asset[];
        metadataItems: Array<MetadataItem<any>>;
    }): Promise<any>;
    /**
     * Get metadata options
     * @param args
     */
    getMetadataItemOptions(args: IMetadataGetMetadataItemOptions): Promise<any>;
    /**
     * Get tree options
     * @param args
     * @returns {Promise}
     */
    getTreeOptions(args: {
        metadataItem: TreeMetadataItem;
        path: string;
    }): Promise<any>;
    /**
     * Get combo options
     * @param args
     * @returns {Promise}
     */
    getComboOptions(args: any): Promise<any>;
    /**
     * Checks if a version is unique
     * @param args
     * @param {Asset} args.asset
     * @param {UniqueVersionMetadataItem} args.metadataItem
     * @returns {Promise}
     */
    verifyUniqueVersion(args: {
        asset: Asset;
        metadataItem: UniqueVersionMetadataItem;
    }): Promise<any>;
    /**
     *
     * @param args
     * @param {Asset} args.sourceAsset
     * @param {Asset} args.targetAsset
     * @returns {Promise}
     */
    copyMetadata(args: {
        sourceAsset: Asset;
        targetAsset: Asset;
    }): Promise<any>;
    /**
     * Creates a last modified metadata items
     * @returns {DateTimeMetadataItem}
     */
    _getLastModifiedMetadataItem(): DateTimeMetadataItem;
    /**
     * Computes a batch value from the metadata item
     * @param metadataItem
     */
    _getUpdateContainerItemFromMetadataItem(metadataItem: MetadataItem<any>): IUpdateContainerAddItemArgs;
}
declare module '../connector' {
    interface Connector {
        metadata: Metadata;
    }
}
