import { Endpoint, IEndpointArgs } from '../common/endpoint';
import { Connector as ConnectorType } from '../connector';
import { Asset } from '../model/asset';
import { UploadTicket } from '../model/ticket/uploadTicket';
import { DigiUploadFile } from '../utilities/digiUploader/IDigiUploader';
import { Notifications } from './notifications';
export interface IUploadEndpointArgs extends IEndpointArgs {
    computerName: string;
    instance: ConnectorType;
    notifications: Notifications;
}
export declare class Upload extends Endpoint {
    private instance;
    private digiUpload;
    private readonly assetCreatedQueue;
    private readonly assetPublishedQueue;
    private readonly notifications;
    /**
     * C-tor
     * @param {Object} args
     * @param {string} args.computerName
     */
    constructor(args: IUploadEndpointArgs);
    /**
     * Returns a promise that resolves to an array of upload tickets
     * @param args
     * @param {File|CloudFile[]} args.files
     * @returns {Promise.<UploadTicket[]>}
     */
    requestUploadTickets(args: {
        files: DigiUploadFile[];
    }): Promise<UploadTicket[]>;
    /**
     * Upload assets from upload tickets
     * @param args
     * @param {UploadTicket[]} args.tickets
     * @returns {Promise.<Asset[]>}
     */
    uploadAssetsByTicket(args: {
        tickets: UploadTicket[];
    }): Promise<Asset[]>;
    /**
     * Uploads an asset from a ticket
     * @param {UploadTicket} ticket
     * @returns {Promise.<Asset[]>}
     */
    _uploadAssetByTicket(ticket: UploadTicket): Promise<Asset>;
    /**
     * Marks an asset as being in publish
     * @param ticket
     */
    _markPublishingInProgress(ticket: UploadTicket): Promise<any>;
    /**
     * Returns a promise that resolves when the asset is created
     * @param asset
     * @returns {Promise}
     */
    awaitAssetCreated(asset: Asset): Promise<unknown>;
    /**
     * @deprecated
     * @param asset
     */
    awaitAssetEditable(asset: Asset): Promise<unknown>;
    /**
     * Returns a promise that resolves when the asset is published
     * @param asset
     * @returns {Promise}
     */
    awaitAssetPublished(asset: Asset): Promise<unknown>;
}
declare module '../connector' {
    interface Connector {
        upload: Upload;
    }
}
