import { Endpoint, IEndpointArgs } from '../common/endpoint';
import { Connector as ConnectorType } from '../connector';
import { Asset } from '../model/asset';
import { AssetVersion } from '../model/assetVersion';
import { ReplaceTicket } from '../model/ticket/replaceTicket';
import { RestoreTicket } from '../model/ticket/restoreTicket';
import { DigiUploadFile } from '../utilities/digiUploader/IDigiUploader';
export interface IVersionEndpointArgs extends IEndpointArgs {
    computerName: string;
    instance: ConnectorType;
}
export declare class Version extends Endpoint {
    private instance;
    private digiUpload;
    /**
     * C-tor
     * @param {Object} args
     * @param {string} args.computerName
     */
    constructor(args: IVersionEndpointArgs);
    /**
     * Returns a promise that resolved to a replace ticket
     * @param args
     * @returns {Promise.<ReplaceTicket>}
     */
    requestReplaceTicket(args: {
        asset: Asset;
        file: DigiUploadFile;
    }): Promise<ReplaceTicket>;
    /**
     * Returns a promise that resolved to a restore ticket
     * @param args
     * @param {Asset} args.asset
     * @param {AssetVersion} args.version
     * @returns {Promise.<RestoreTicket>}
     */
    requestRestoreTicket(args: {
        asset: Asset;
        version: AssetVersion;
    }): Promise<RestoreTicket>;
    /**
     * Replace asset from ticket
     * @param args
     * @param {ReplaceTicket} args.ticket
     * @returns {Promise.<>}
     */
    replaceAssetByTicket(args: {
        ticket: ReplaceTicket;
    }): Promise<any>;
    /**
     * Restore an asset from ticket
     * @param args
     * @param {ReplaceTicket} args.ticket
     * @returns {Promise.<>}
     */
    restoreAssetByTicket(args: {
        ticket: ReplaceTicket;
    }): Promise<void>;
    /**
     * Get a list of asset versions
     * @param args
     * @param {Asset} args.asset
     * @returns {Promise.<AssetVersion[]>}
     */
    getAssetVersions(args: {
        asset: Asset;
    }): Promise<AssetVersion[]>;
    /**
     * Marks an asset as being in publish
     * @param ticket
     */
    private _markPublishingInProgress;
}
declare module '../connector' {
    interface Connector {
        version: Version;
    }
}
