export interface IUpdateContainerAddItemArgs {
    fieldName?: string;
    valueType?: number;
    value?: any;
    fieldId?: string;
    fieldProperties?: {
        labelId?: number;
        standardGuid?: string;
    };
    [key: string]: any;
}
export interface IUpdateContainerJson {
    Id: any;
    FieldId: any;
    FieldName: string;
    ContainerType: any;
    ItemIds: number[];
    RowId: number;
    Values: Array<{
        FieldId: (string | any);
        Type: (string | number | any);
        Values: any[];
    }>;
}
export declare class UpdateContainer {
    rowId: number;
    containerId: any;
    type: any;
    private containerItems;
    private itemIds;
    private containerFieldName;
    /**
     * C-tor
     * @param {Object} args
     * @param {Number} args.type
     * @param {Number[]} args.itemIds
     * @param {String} [args.id]
     * @param {String} [args.fieldName]
     * @param {Number} [args.rowId]
     */
    constructor(args: {
        type?: number;
        itemIds?: number[];
        id?: string;
        fieldName?: string;
        rowId?: number | string;
    });
    static get ROW_ID(): {
        NonIncremental: number;
    };
    /**
     * Batch types
     */
    static get CONTAINER_TYPE(): {
        Values: number;
        Delete: number;
        ValuesRowid: number;
        DeleteRowid: number;
        ItemIdsValues: number;
        ItemIdsDelete: number;
        ItemIdsValuesRowid: number;
        ItemIdsDeleteRowid: number;
    };
    /**
     * Value types
     */
    static get VALUE_TYPE(): {
        String: number;
        Bool: number;
        Int: number;
        DateTime: number;
        Float: number;
        IntList: number;
        Folder: number;
        AssetType: number;
        StringRow: number;
        BoolRow: number;
        IntRow: number;
        DateTimeRow: number;
        FloatRow: number;
        IntListRow: number;
        Delete: number;
        ValueExtraValue: number;
        StringList: number;
        StringListRow: number;
    };
    /**
     * Append a value to the container
     * @param {Object}  args
     * @param {String} args.fieldName
     * @param {Number} args.valueType
     * @param {*} args.value
     * @param {String} [args.fieldId]
     * @param {Object} [args.fieldProperties]
     */
    addItem(args: IUpdateContainerAddItemArgs): void;
    /**
     * Create an XML snippet for a given item in container
     * @param thisItem
     * @returns {string}
     * @private
     */
    _getItemXml(thisItem: IUpdateContainerAddItemArgs): string;
    /**
     * Returns the XML part of the UpdateContainer
     * PS: I am not insane! I am choosing to build the XML using string gymnastics
     * because XML and DOM APIs are not available natively on nodejs or workers.
     *
     * @returns {string}
     */
    getContainerXML(): string;
    /**
     * JSON parts of the batch
     */
    getContainerJSON(): IUpdateContainerJson;
    /**
     * Returns the container values of the JSON
     * @returns {Array}
     */
    private _getContainerJSONValues;
}
